#!/usr/bin/env bash

###
# http://stackoverflow.com/a/23342259
###
exe() { echo "\$ $@" ; "$@" ; }

show_usage () {
  echo ""
  echo "Set up the building of libssts and clean up too."
  echo "  ./build.sh clean      -  Clean up the project and build files."
  echo ""
  echo "  ./build.sh build      -  Create the build directory, run CMake (if"
  echo "                           needed) and build libssts."
  echo ""
  echo "  ./build.sh help       -  Show this helpful help text."
  echo ""
  echo "  ./build.sh clean-tree -  clean the bzr three. reverting all and any"
  echo "                           changes made to the file tree since the last"
  echo "                           commit."
}

do_build () {
  if ( ! -d "./build" )
  then
    exe mkdir ./build
  fi
  
  cd ./build
  
  if [ ! -f "Makefile" ]
  then
    exe cmake ..
  fi
  
  make
}

do_clean () {
  if [ -d "./build" ]
  then
    exe rm -R ./build
  fi
}

do_clean_tree () {
  exe bzr revert
  exe bzr clean-tree 
}

case $1 in
     "help"|"-h") show_usage ;;
     "clean") do_clean ;;
     "build"|"") do_build ;;
     "clean-tree") do_clean_tree ;;
     *) show_usage ;;
esac



